# ConnectorStatsMetadata

Information about an ConnectorStats object. Useful to understand when stats were published or updated. 
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**creation_time** | **datetime** | When the statistics were first created | [optional] [readonly] 
**collection_time** | **datetime** | When the statistics were collected | 
**receipt_time** | **datetime** | When the statistics were received for storage | [optional] [readonly] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


